function [delta, sca, scb, scc, curvature] = commodity(TBsba,Unit,calib)

filecalib = calib;
worksheet = 'Commodity';
rho_Comm_range1 = 'C3:M8';
rho_Comm = xlsread(filecalib,worksheet,rho_Comm_range1 );
gamma_Comm_range1 = 'C18:M28';
gamma_Comm = xlsread(filecalib,worksheet,gamma_Comm_range1);

%% ***************************************************************
% Delta risk
%*****************************************************************
% Load the delta risks contribution

Sk = TBsba(100:110,9:14);
WS2 = TBsba(100:110,8);
WS = TBsba(100:110,7);

% Change data into units
% [Note: Summations of WS2/rho+/rho- should be reported in unit^2]
% As set out in the General Info worksheet, banks may set reporting unit to 1, 1000, 1000000
% Unit = xlsread(filebank, 'General Info', 'C50');
Sk = Sk * (Unit^2);
WS2 = WS2 * (Unit^2);
WS = WS * (Unit);
% Calculate Kb
Kb = sqrt(max(0,WS2 + diag(Sk * rho_Comm)));
% Compute total delta capital
K_Comm_Delta = sqrt(max(0,(Kb') * Kb + (WS')*(gamma_Comm)*(WS) - (WS')*(WS)));
% Convert Kb, K_Comm_Delta back into reporting unit
% The vector Kb is to be reported in cell F100:F110
% This is to be reported in cell F113
Kb = Kb / Unit;
K_Comm_Delta = K_Comm_Delta / Unit;

% Output of the commodity function: delta
delta = K_Comm_Delta;

%% ***************************************************************
% Vega risk
%*****************************************************************
% Load the vega risks contribution common to all three scenarios
WS = TBsba(100:110,16);
WS2 = TBsba(100:110,17);
% Change data into units
WS2 = WS2 * (Unit^2);
WS = WS * (Unit);
%% ***************************************************************
% [Scenario a]
% Load the vega risks contribution on scenario a
SSa = TBsba(100:110,18);
% [Note: As stated on page 121 of the QIS instructions, data input of SSa should include multiplication by rho parameters. These parameters are specified in FAQ 6.3.3]
% Change data into units
SSa = SSa * (Unit^2);
% Calculate Kb on scenario a
Kb = sqrt(max(0,WS2 + SSa));
% Compute total vega risk capital for Comdty under scenario a
K_Comm_Vega_ScenarioA = sqrt(max(0,(Kb') * Kb + (WS')*(gamma_Comm)*(WS) - (WS')*WS));
% Convert Kb, K_Comm_Vega_ScenarioA back into reporting units
% The vector Kb should be reported in O100:O110
% The number K_Comm_Vega_ScenarioA should be reported in F115
Kb = Kb / Unit;
K_Comm_Vega_ScenarioA = K_Comm_Vega_ScenarioA / Unit;
% Output of the commodity function: sca
sca = K_Comm_Vega_ScenarioA;


%% ***************************************************************
% [Scenario b]
% Load the vega risks contribution on scenario b

SSb = TBsba(100:110,19);
% [Note: As stated on page 121 of the QIS instructions, data input of SSb should include multiplication by rho parameters. These parameters are specified in FAQ 6.3.3]
% Change data into units
SSb = SSb * (Unit^2);
% Calculate Kb on scenario b
Kb = sqrt(max(0,WS2 + SSb));
% Compute total vega capital for Comdty under scenario b
K_Comm_Vega_ScenarioB = sqrt(max(0,(Kb') * Kb + (WS')*(gamma_Comm)*(WS) - (WS')*WS));
% Convert K_Comm_Vega_ScenarioB back into reporting unit
% The number K_Comm_Vega_ScenarioB should be reported in F116
K_Comm_Vega_ScenarioB = K_Comm_Vega_ScenarioB / Unit;
% Output of the commodity function: scb
scb = K_Comm_Vega_ScenarioB;

%% ***************************************************************
% [Scenario c]
% Load the vega risks contribution on scenario c
SSc = TBsba(100:110,19);
% [Note: As stated on page 121 of the QIS instructions, data input of SSc should include multiplication by rho parameters. These parameters are specified in FAQ 6.3.3]
% Change data into units
SSc = SSc * (Unit^2);
% Calculate Kb on scenario c
Kb = sqrt(max(0,WS2 + SSc));
% Compute total vega capital for Comdty under scenario c
K_Comm_Vega_ScenarioC = sqrt(max(0,(Kb') * Kb + (WS')*(gamma_Comm)*(WS) - (WS')*WS));
% Convert K_Comm_Vega_ScenarioC back into reporting unit
% The number K_Comm_Vega_ScenarioC should be reported in F117
K_Comm_Vega_ScenarioC = K_Comm_Vega_ScenarioC / Unit;
% Output of the commodity function: scc
scc = K_Comm_Vega_ScenarioC;

%% ***************************************************************
% Curvature risk
%*****************************************************************
% Load parameters
worksheet = 'Commodity';
rho_Comm_range3 = 'C12:M13';
rho_Comm_curvature = xlsread(filecalib,worksheet,rho_Comm_range3);
gamma_Comm_range2 = 'C33:M43';
gamma_Comm_curvature = xlsread(filecalib,worksheet,gamma_Comm_range2);
% Set the main input variables
% worksheet = 'TB SBA';
% Load the curvature risk contribution
Sk_curvature = TBsba(100:110,24:25);
SCvr = TBsba(100:110,22);
Smax_Cvr = TBsba(100:110,23);
% Change data into units
Sk_curvature = Sk_curvature * (Unit^2);
SCvr = SCvr * (Unit);
Smax_Cvr = Smax_Cvr * (Unit^2);
% Calculate Kb
Kb = sqrt(max(0,Smax_Cvr + diag(Sk_curvature * rho_Comm_curvature)));
% Compute total non-linear capital for Comdty
XbYc = ones(11);
% [Apply function Phi]
for b = 1:11
for c = 1:11
if SCvr(b)<0 && SCvr(c)<0
XbYc(b,c)=0;
end
end
end
K_Comm_Curvature = sqrt(max(0, (Kb') * Kb + (SCvr')*((gamma_Comm_curvature).*(XbYc))*(SCvr) - (SCvr')*(diag(diag(XbYc)))*(SCvr)));
% Convert Kb and K_Comm_Curvature back into reporting unit
% The vector Kb should be reported in U100:U110
% The number K_Comm_Curvature should be reported in F118
Kb = Kb / Unit;
K_Comm_Curvature = K_Comm_Curvature / Unit;
% Output of the commodity function: curvature
curvature = K_Comm_Curvature;

end