function [delta, sca, scb, scc, curvature] = csr(TBsba,Unit,calib)

% Computation of standardised capital charges for delta, vega, and curvature risk of non-securitisation Credit Spread Risk(CSR).

%% Load parameters

filecalib = calib;
worksheet = 'CSR_non_sec';
rho_csr_non_sec_range1 = 'C2:C11';
rho_csr_non_sec = xlsread(filecalib,worksheet,rho_csr_non_sec_range1);
rho_csr_non_sec_range2 = 'C12:C13';
rho_csr_non_sec_residual = xlsread(filecalib,worksheet,rho_csr_non_sec_range2);
gamma_csr_non_sec_range1 = 'B24:M35';
gamma_csr_non_sec = xlsread(filecalib,worksheet,gamma_csr_non_sec_range1);

%% ***************************************************************
% Delta risk
%*****************************************************************
% Load the delta risks contribution

Sk = TBsba(50:61,9:18);
WS2 = TBsba(50:61,8);
WS = TBsba(50:61,7);
Sk_residual = TBsba(62,9:10);
WS2_residual = TBsba(62,8);
% Change data into units
% [Note: Summations of WS2/rho+/rho- should be reported in unit^2]
% As set out in the General Info worksheet, banks may set reporting unit to 1, 1000, 1000000
% Unit = xlsread(filebank, 'General Info', 'C50');
Sk = Sk * (Unit^2);
WS2 = WS2 * (Unit^2);
WS = WS * (Unit);
Sk_residual = Sk_residual * (Unit^2);
WS2_residual = WS2_residual * (Unit^2);
% Calculate Kb
Kb = sqrt(max(0,WS2 + Sk * rho_csr_non_sec));
Kb_residual = sqrt(max(0,WS2_residual + Sk_residual * rho_csr_non_sec_residual));
% Compute total delta capital
K_csr_non_sec_Delta = sqrt(max(0,(Kb') * Kb + (WS')*(gamma_csr_non_sec)*(WS) - (WS')*(WS))) + Kb_residual;
% Convert Kb, Kb_residual, K_csr_non_sec_Delta back into reporting units
% The vector Kb and Kb_residual should be reported in F50:F61 and F62
% The number K_csr_non_sec_Delta should be reported in F65
Kb = Kb / Unit;
Kb_residual = Kb_residual / Unit;
K_csr_non_sec_Delta = K_csr_non_sec_Delta / Unit;
% Output of the csr function: delta
delta = K_csr_non_sec_Delta;

%% ***************************************************************
% Vega risk
%*****************************************************************
% Load the vega risks contribution common to all three scenarios
WS = TBsba(50:61,20);
WS2 = TBsba(50:61,21);
WS2_residual = TBsba(62,21);
% Change data into units
WS = WS * (Unit);
WS2 = WS2 * (Unit^2);
WS2_residual = WS2_residual* (Unit^2);
%%***************************************************************
% [Scenario a]
% Load the vega risks contribution on scenario a
SSa = TBsba(50:61,22);
SSa_residual = TBsba(62,22);
% [Note: As stated on page 121 of the QIS instructions, data input of SSa should include multiplication by rho parameters. These parameters are specified in FAQ 6.3.3]
% Change data into units
SSa = SSa * (Unit^2);
SSa_residual = SSa_residual* (Unit^2);
% Calculate Kb on scenario a
Kb = sqrt(max(0,WS2 + SSa));
Kb_residual = sqrt(max(0,WS2_residual + SSa_residual));
% Compute total vega risk capital for csr_non_sec under scenario a
K_csr_non_sec_Vega_ScenarioA = sqrt(max((Kb') * Kb + (WS')*(gamma_csr_non_sec)*(WS) - (WS')*WS,0)) + Kb_residual;
% Convert Kb, Kb_residual and K_csr_non_sec_Vega_ScenarioA back into reporting units
% The vector Kb should be reported in S50:S61 and S62
% The number K_csr_non_sec_Vega_ScenarioA should be reported in F67
Kb = Kb / Unit;
Kb_residual = Kb_residual / Unit;
K_csr_non_sec_Vega_ScenarioA = K_csr_non_sec_Vega_ScenarioA / Unit;
% Output of the csr function: sca
sca = K_csr_non_sec_Vega_ScenarioA;

%% ***************************************************************
% [Scenario b]
% Load the vega risks contribution on scenario b
SSb = TBsba(50:61,23);
SSb_residual = TBsba(62,23);
% [Note: As stated on page 121 of the QIS instructions, data input of SSb should include multiplication by rho parameters. These parameters are specified in FAQ 6.3.3]
% Change data into units
SSb = SSb * (Unit^2);
SSb_residual = SSb_residual* (Unit^2);
% Calculate Kb on scenario b
Kb = sqrt(max(0,WS2 + SSb));
Kb_residual = sqrt(max(0,WS2_residual + SSb_residual));
% Compute total vega capital for csr_non_sec under scenario b
K_csr_non_sec_Vega_ScenarioB = sqrt(max((Kb') * Kb + (WS')*(gamma_csr_non_sec)*(WS) - (WS')*WS,0)) + Kb_residual;
% Convert K_csr_non_sec_Vega_ScenarioB back into reporting unit
% The number K_csr_non_sec_Vega_ScenarioB should be reported in F68
K_csr_non_sec_Vega_ScenarioB = K_csr_non_sec_Vega_ScenarioB / Unit;
% Output of the csr function: scb
scb = K_csr_non_sec_Vega_ScenarioB;

%% ***************************************************************
% [Scenario c]
% Load the vega risks contribution on scenario c
SSc = TBsba(50:61,24);
SSc_residual = TBsba(62,24);
% [Note: As stated on page 121 of the QIS instructions, data input of SSc should include multiplication by rho parameters. These parameters are specified in FAQ 6.3.3]
% Change data into units
SSc = SSc * (Unit^2);
SSc_residual = SSc_residual* (Unit^2);
% Calculate Kb on scenario c
Kb = sqrt(max(0,WS2 + SSc));
Kb_residual = sqrt(max(0,WS2_residual + SSc_residual));
% Compute total vega capital for csr_non_sec under scenario c
K_csr_non_sec_Vega_ScenarioC = sqrt(max((Kb') * Kb + (WS')*( gamma_csr_non_sec)*(WS) - (WS')*WS,0)) + Kb_residual;
% Convert K_csr_non_sec_Vega_ScenarioC back into reporting unit
% The number K_csr_non_sec_Vega_ScenarioC should be reported in F69
K_csr_non_sec_Vega_ScenarioC = K_csr_non_sec_Vega_ScenarioC / Unit;
% Output of the csr function: scc
scc = K_csr_non_sec_Vega_ScenarioC;

%% ***************************************************************
% Curvature risk
%*****************************************************************
% Load parameters
worksheet = 'CSR_non_sec';
rho_csr_non_sec_range3 = 'C39:C40';
rho_csr_non_sec_curvature = xlsread(filecalib,worksheet,rho_csr_non_sec_range3);
gamma_csr_non_sec_range2 = 'B48:M59';
gamma_csr_non_sec_curvature = xlsread(filecalib,worksheet,gamma_csr_non_sec_range2);
% Set the main input variables
worksheet = 'TB SBA';
% Load the curvature risk contribution

Sk_curvature = TBsba(50:61,28:29);
Sk_curvature_residual = TBsba(62,28);
SCvr = TBsba(50:61,26);
Smax_Cvr = TBsba(50:61,27);
Smax_Cvr_residual = TBsba(62,27);
% Change data into units
Sk_curvature = Sk_curvature * (Unit^2);
Sk_curvature_residual = Sk_curvature_residual * (Unit^2);
Smax_Cvr = Smax_Cvr * (Unit^2);
Smax_Cvr_residual = Smax_Cvr_residual * (Unit^2);
SCvr = SCvr * (Unit);

%% Calculate Kb and Kb_residual
Kb = sqrt(max(0,Smax_Cvr + Sk_curvature * rho_csr_non_sec_curvature));
Kb_residual = sqrt(max(0,Smax_Cvr_residual + Sk_curvature_residual));
%% Compute total non-linear capital for csr_non_sec_Curvature
XbYc = ones(12);
% [Apply function Phi]
for b = 1:12
for c = 1:12
if SCvr(b)<0 && SCvr(c)<0
XbYc(b,c)=0;
end
end
end
K_csr_non_sec_Curvature = sqrt(max(0,...
(Kb') * Kb +...
(SCvr')*((gamma_csr_non_sec_curvature).*(XbYc))*(SCvr) -...
(SCvr')*(diag(diag(XbYc)))*(SCvr))...
) + Kb_residual;
% Convert Kb, Kb_residual, K_csr_non_secCurvature back into reporting unit
% The vector Kb and Kb_residual should be reported in Y50:Y61 and Y62
% The number K_csr_non_sec_Curvature should be reported in F70
Kb = Kb / Unit;
Kb_residual = Kb_residual / Unit;
K_csr_non_sec_Curvature = K_csr_non_sec_Curvature / Unit;
% Output of the csr function: curvature
curvature = K_csr_non_sec_Curvature;

end