function [delta, sca, scb, scc, curvature] = equity(TBsba,Unit,calib)

% Computation of standardised capital charges for delta, vega, and curvature risk of Equity Risk.
%% Load parameters
filecalib = calib;
worksheet = 'Equity';
rho_Equity_range1 = 'C3:L8';
rho_Equity = xlsread(filecalib,worksheet,rho_Equity_range1 );
rho_Equity_range2 = 'M3:M4';
rho_Equity_residual = xlsread(filecalib,worksheet,rho_Equity_range2);
gamma_Equity_range1 = 'C18:L27';
gamma_Equity = xlsread(filecalib,worksheet,gamma_Equity_range1);

%% ***************************************************************
% Delta risk
%*****************************************************************
% Load the delta risks contribution

Sk = TBsba(76:85,9:14);
WS2 = TBsba(76:85,8);
WS = TBsba(76:85,7);
Sk_residual = TBsba(86,9:10);
WS2_residual = TBsba(86,8);
% Change data into units
% [Note: Summations of WS2/rho+/rho- should be reported in unit^2]
% As set out in the General Info worksheet, banks may set reporting unit to 1, 1000, 1000000
Sk = Sk * (Unit^2);
WS2 = WS2 * (Unit^2);
WS = WS * (Unit);
Sk_residual = Sk_residual * (Unit^2);
WS2_residual = WS2_residual * (Unit^2);
% Calculate Kb
Kb = sqrt(max(0,WS2 + diag(Sk * rho_Equity)));
Kb_residual = sqrt(max(0,WS2_residual + Sk_residual * rho_Equity_residual));
% Compute total delta capital
K_Equity_Delta = sqrt(max(0,(Kb') * Kb + (WS')*(gamma_Equity)*(WS) - (WS')*(WS))) + Kb_residual ;
% Converting Kb, Kb_residual and K_Equity_Delta back into reporting units
% The vector Kb and Kb_residual should be reported in F76:F85 and F86
% The number K_Equity_Delta should be reported in F89
Kb = Kb / Unit;
Kb_residual = Kb_residual /Unit;
K_Equity_Delta = K_Equity_Delta / Unit;
% Output of the equity function: delta
delta = K_Equity_Delta;

%% ***************************************************************
% Vega risk
%*****************************************************************
% Load the vega risks contribution common to all three scenarios
WS = TBsba(76:85,16);
WS2 = TBsba(76:85,17);
WS2_residual = TBsba(86,17);

% Change data into units
WS = WS * (Unit);
WS2 = WS2 * (Unit^2);
WS2_residual = WS2_residual * (Unit^2);
%% ***************************************************************
% [Scenario a]
% Load the vega risks contribution on scenario a

SSa = TBsba(76:85,18);
SSa_residual = TBsba(86,18);
% [Note: As stated on page 121 of the QIS instructions, data input of SSa should include multiplication by rho parameters. These parameters are specified in FAQ 6.3.3]
% Change data into units
SSa = SSa * (Unit^2);
SSa_residual = SSa_residual * (Unit^2);
% Calculate Kb on scenario a
Kb = sqrt(max(0,WS2 + SSa));
Kb_residual = sqrt(max(0,WS2_residual + SSa_residual));
% Compute total vega risk capital for Equity under scenario a
K_Equity_Vega_ScenarioA = sqrt(max(0,(Kb') * Kb + (WS')*(gamma_Equity)*(WS) - (WS')*WS)) + Kb_residual;
% Convert Kb, Kb_residual, K_Equity_Vega_ScenarioA back into reporting units
% The vector Kb and Kb_residual should be reported in O76:O85 and O86
% The number K_Equity_Vega_ScenarioA should be reported in F91
Kb = Kb / Unit;
Kb_residual = Kb_residual / Unit;
K_Equity_Vega_ScenarioA = K_Equity_Vega_ScenarioA / Unit;
% Output of the equity function: sca
sca = K_Equity_Vega_ScenarioA;

%% ***************************************************************
% [Scenario b]
% Load the vega risks contribution on scenario b

SSb = TBsba(76:85,19);
SSb_residual = TBsba(86,19);
% [Note: As stated on page 121 of the QIS instructions, data input of SSb should include multiplication by rho parameters. These parameters are specified in FAQ 6.3.3]
% Change data into units
SSb = SSb * (Unit^2);
SSb_residual = SSb_residual * (Unit^2);
% Calculate Kb on scenario b
Kb = sqrt(max(0,WS2 + SSb));
Kb_residual = sqrt(max(0,WS2_residual + SSb_residual));
% Compute total vega capital for Equity under scenario b
K_Equity_Vega_ScenarioB = sqrt(max(0,(Kb') * Kb + (WS')*(gamma_Equity)*(WS) - (WS')*WS)) + Kb_residual;
% Convert K_Equity_Vega_ScenarioB back into reporting units
% The number K_Equity_Vega_ScenarioB should be reported in F92
K_Equity_Vega_ScenarioB = K_Equity_Vega_ScenarioB / Unit;
% Output of the equity function: scb
scb = K_Equity_Vega_ScenarioB;

%% ***************************************************************
% [Scenario c]
% Load the vega risks contribution on scenario c
SSc = TBsba(76:85,20);
SSc_residual = TBsba(86,20);
% [Note: As stated on page 121 of the QIS instructions, data input of SSc should include multiplication by rho parameters. These parameters are specified in FAQ 6.3.3]
% Change data into units
SSc = SSc * (Unit^2);
SSc_residual = SSc_residual * (Unit^2);
% Calculate Kb on scenario c
Kb = sqrt(max(0,WS2 + SSc));
Kb_residual = sqrt(max(0,WS2_residual + SSc_residual));
% Compute total vega capital for Equity under scenario c
K_Equity_Vega_ScenarioC = sqrt(max(0,(Kb') * Kb + (WS')*(gamma_Equity)*(WS) - (WS')*WS)) + Kb_residual;
% Convert K_Equity_Vega_ScenarioC back into reporting unit
% The number K_Equity_Vega_ScenarioC should be reported in F93
K_Equity_Vega_ScenarioC = K_Equity_Vega_ScenarioC / Unit;
% Output of the equity function: scc
scc = K_Equity_Vega_ScenarioC;

%% ***************************************************************
% Curvature risk
%*****************************************************************
% Load parameters
worksheet = 'Equity';
rho_Equity_range3 = 'C12:L13';
rho_Equity_curvature = xlsread(filecalib,worksheet,rho_Equity_range3);
gamma_Equity_range2 = 'C33:L42';
gamma_Equity_curvature = xlsread(filecalib,worksheet,gamma_Equity_range2);
% Load the curvature risk contribution
Sk_curvature = TBsba(76:85,24:25);
Sk_curvature_residual = TBsba(86,24);
SCvr = TBsba(76:85,22);
Smax_Cvr = TBsba(76:85,23);
Smax_Cvr_residual = TBsba(86,23);
% Change data into units
Sk_curvature = Sk_curvature * (Unit^2);
Sk_curvature_residual = Sk_curvature_residual * (Unit^2);
Smax_Cvr = Smax_Cvr * (Unit^2);
Smax_Cvr_residual = Smax_Cvr_residual * (Unit^2);
SCvr = SCvr * (Unit);
%% Calculate Kb and Kb_residual
Kb = sqrt(max(0,Smax_Cvr + diag(Sk_curvature * rho_Equity_curvature)));
Kb_residual = sqrt(max(0,Smax_Cvr_residual + Sk_curvature_residual));
% Compute total non-linear capital for Equity
XbYc = ones(10);
% [Apply function Phi]
for b = 1:10
for c = 1:10
if SCvr(b)<0 && SCvr(c)<0
XbYc(b,c)=0;
end
end
end
K_Equity_Curvature = sqrt(max(0, (Kb') * Kb + (SCvr')*((gamma_Equity_curvature).*(XbYc))*(SCvr) - (SCvr')*(diag(diag(XbYc)))*(SCvr))) + Kb_residual;
% Converting Kb, Kb_residual, and K_Equity_Curvature back into reporting units
% The vector Kb and Kb_residual should be reported in U76:U85 and U86
% The number K_Equity_Curvature should be reported in F94
Kb = Kb / Unit;
Kb_residual = Kb_residual / Unit;
K_Equity_Curvature = K_Equity_Curvature / Unit;
% Output of the equity function: curvature
curvature = K_Equity_Curvature;

end