
function [delta, sca, scb, scc, curvature,Unit,Swsdelta,Swsvega,Swscurvature] = fx(TBsba,Unit,calib)


% Computation of standardised capital charges for delta, vega, and curvature risk of FX risk.
% Load parameters
filecalib = calib;
worksheet = 'FX';
rho_FX_range1 = 'C2:C7';
rho_FX = xlsread(filecalib,worksheet,rho_FX_range1);
gamma_FX = (0.6)*ones(30);

%% ***************************************************************
% Delta risk
%*****************************************************************
% Load the delta risks contribution

Sk = TBsba(125:154,9:14);
WS2 = TBsba(125:154,8);
WS = TBsba(125:154,7);
% Change data into units
% [Note: Summations of WS2/rho+/rho- should be reported in unit^2]
% As set out in the General Info worksheet, banks may set reporting unit to 1, 1000, 1000000
% Unit = xlsread(filebank, 'General Info', 'C50');
Sk = Sk * (Unit^2);
WS2 = WS2 * (Unit^2);
WS = WS * (Unit);
% Export to "main" WS for simplified SBA
Swsdelta = WS;
% Calculate Kb
Kb = sqrt(max(0,WS2 + Sk * rho_FX));
% Compute total delta capital for listed currencies
K_FX_Delta = sqrt(max(0,(Kb') * Kb + (WS')*(gamma_FX)*(WS) - (0.6)*(WS')*(WS)));
% Convert Kb and K_FX_Delta back into reporting units
% The vector Kb should be reported in F125:F154
% The number K_FX_Delta should be reported in F159
Kb = Kb / Unit;
K_FX_Delta = K_FX_Delta / Unit;
% Output of the fx function: delta
delta = K_FX_Delta;

%% ***************************************************************
% Vega risk
%*****************************************************************
% Load the vega risks contribution common to all three scenarios

WS = TBsba(125:154,16);
WS2 = TBsba(125:154,17);
% Change data into units
WS = WS * (Unit);
WS2 = WS2 * (Unit^2);
% Export to "main" WS for simplified SBA
Swsvega = WS;
%% ***************************************************************
% [Scenario a]
% Load the vega risks contribution on scenario a

SSa = TBsba(125:154,18);
% [Note: As stated on page 121 of the QIS instructions, data input of SSa should include multiplication by rho parameters. These parameters are specified in FAQ 6.3.3]
% Change data into units
SSa = SSa * (Unit^2);
% Calculate Kb on scenario a
Kb = sqrt(max(0,WS2 + SSa));
% Compute total vega capital for FX under scenario a for listed currencies
K_FX_Vega_ScenarioA = sqrt(max(0,(Kb') * Kb + (WS')*gamma_FX*(WS) - (0.6)*(WS')*(WS)));
% Convert Kbs and K_FX_Vega_ScenarioA back into reporting units
% The vector Kb should be reported in O125:O154
% The number K_FX_Vega_ScenarioA should be reported in F161
Kb = Kb / Unit;
K_FX_Vega_ScenarioA = K_FX_Vega_ScenarioA / Unit;
% Output of the fx function: sca
sca = K_FX_Vega_ScenarioA;

%% ***************************************************************
% [Scenario b]
% Load the vega risks contribution on scenario b

SSb = TBsba(125:154,19);
% [Note: As stated on page 121 of the QIS instructions, data input of SSb should include multiplication by rho parameters. These parameters are specified in FAQ 6.3.3]
% Change data into units
SSb = SSb * (Unit^2);
% Calculate Kb on scenario b
Kb = sqrt(max(0,WS2 + SSb));
% Compute total vega capital for FX under scenario b for listed currencies
K_FX_Vega_ScenarioB = sqrt(max(0,(Kb') * Kb + (WS')*gamma_FX*(WS) - (0.6)*(WS')*(WS)));
% Convert K_FX_Vega_ScenarioB back into reporting units
% The number K_FX_Vega_ScenarioB should be reported in F162
K_FX_Vega_ScenarioB = K_FX_Vega_ScenarioB / Unit;
% Output of the fx function: scb
scb = K_FX_Vega_ScenarioB;

%% ***************************************************************
% [Scenario c]
% Load the vega risks contribution on scenario c

SSc = TBsba(125:154,20);
% [Note: As stated on page 121 of the QIS instructions, data input of SSc should include multiplication by rho parameters. These parameters are specified in FAQ 6.3.3]
% Change data into units
SSc = SSc * (Unit^2);
% Calculate Kb on scenario c
Kb = sqrt(max(0,WS2 + SSc));
% Compute total vega capital for FX under scenario c for listed currencies
K_FX_Vega_ScenarioC = sqrt(max(0,(Kb') * Kb + (WS')*gamma_FX*(WS) - (0.6)*(WS')*(WS)));
% Convert K_FX_Vega_ScenarioC back into reporting units
% The number K_FX_Vega_ScenarioC should be reported in F163
K_FX_Vega_ScenarioC = K_FX_Vega_ScenarioC / Unit;
% Output of the fx function: scc
scc = K_FX_Vega_ScenarioC;

%% ***************************************************************
% Curvature risk
%*****************************************************************
% Load parameters
worksheet = 'FX';
rho_FX_range2 = 'C15:C20';
rho_FX_curvature = xlsread(filecalib,worksheet,rho_FX_range2);
% Set the main input variables
% worksheet = 'TB SBA';
% Load the curvature risk contribution
Sk_curvature = TBsba(125:154,24:29);
SCvr = TBsba(125:154,22);
Smax_Cvr = TBsba(125:154,23);
% Change data into units
Sk_curvature = Sk_curvature * (Unit^2);
Smax_Cvr = Smax_Cvr * (Unit^2);
SCvr = SCvr *(Unit);
% Export to "main" WS for simplified SBA
Swscurvature = SCvr;
% Calculate Kb
Kb = sqrt(max(0,Smax_Cvr + Sk_curvature * rho_FX_curvature));
% Compute total non-linear capital for listed currencies
gamma_FX_curvature = (0.6)*(0.6)*ones(30);
XbYc = ones(30);
% [Apply function Phi]
for b = 1:30
for c = 1:30
if SCvr(b)<0 && SCvr(c)<0
XbYc(b,c)=0;
end
end
end
K_FX_Curvature = sqrt(max(0, (Kb') * Kb + (SCvr')*((gamma_FX_curvature).*(XbYc))*(SCvr) - (SCvr')*(0.6*0.6*diag(diag(XbYc)))*(SCvr)));
% Convert Kb and K_FX_Curvature back into reporting units
% The vector Kb should be reported in U125:U154
% The number K_FX_Curvature should be reported in F164
Kb = Kb / Unit;
K_FX_Curvature = K_FX_Curvature / Unit;

% Output of the fx function: curvature
curvature = K_FX_Curvature;

end