
function [delta, sca, scb, scc, curvature] = girr(TBsba,Unit,calib)

% Computation of standardised capital charges for delta, vega and curvature General Interest Rate Risk (listed currencies).

%% Load parameters
file = calib;
worksheet = 'GIRR';
rho_girr_range = 'C2:C223';
rho_girr = xlsread(file,worksheet,rho_girr_range);

%% ***************************************************************
% Delta risk
%*****************************************************************
% Load the delta risks contribution
Sk = TBsba(6:35,9:230);
WS2 = TBsba(6:35,8);
% Change data into units
% [Note: Summations of WS2/rho+/rho- should be reported in unit^2]
% As set out in the General Info worksheet, banks may set reporting unit to 1, 1000, 1000000
Sk = Sk * (Unit^2);
WS2 = WS2 * (Unit^2);
% Calculate Kb
Kb = sqrt(max(WS2 + Sk * rho_girr,0));
% Compute total delta capital for listed currencies
WS = TBsba(6:35,7);
WS = WS * Unit;
Gamma = 0.5;
K_Girr_Listed_Delta = sqrt(max((Kb') * Kb + (WS')*(ones(30)*Gamma)*(WS) - Gamma*(WS')*WS,0));
% Convert Kbs and K back into reporting units
% The vector Kb should be reported in F6:F35
% The number K_Girr_Listed_Delta should be reported in F39Kb = Kb / Unit;
K_Girr_Listed_Delta = K_Girr_Listed_Delta / Unit;
% Output of the girr function: delta
delta = K_Girr_Listed_Delta;

%% ***************************************************************
% Vega risk
%*****************************************************************
% Load the vega risks contribution common to all three scenarios
WS2 = TBsba(6:35,233);
WS = TBsba(6:35,232);
% Change data into units
WS2 = WS2 * (Unit^2);
WS = WS * Unit;

%% ***************************************************************
% Scenario a
% Load the vega risks contribution on scenario a
SSa = TBsba(6:35,234);
% [Note: As stated on page 121 of the QIS instructions, data input of SSa should include multiplication by rho parameters. These parameters are specified in FAQ 6.3.3]
% Change data into units
SSa = SSa * (Unit^2);
% Calculate Kb on scenario a
Kb = sqrt(max(WS2 + SSa,0));
% Compute total vega risk capital for listed currencies under scenario a
K_Girr_Listed_Vega_ScenarioA = sqrt(max((Kb') * Kb + (WS')*(ones(30)*Gamma)*(WS) - Gamma*(WS')*WS,0));
% Convert Kbs and K_Girr_Listed_Vega_ScenarioA back into reporting units
% The vector Kb should be reported in HW6:HW35
% The number K_Girr_Listed_Vega_ScenarioA should be reported in F41
Kb = Kb / Unit;
K_Girr_Listed_Vega_ScenarioA = K_Girr_Listed_Vega_ScenarioA / Unit;
% Output of the girr function: sca
sca = K_Girr_Listed_Vega_ScenarioA;

%% ***************************************************************
% Scenario b
% Load the vega risks contribution on scenario b
SSb = TBsba(6:35,235);
% [Note: As stated on page 121 of the QIS instructions, data input of SSb should include multiplication by rho parameters. These parameters are specified in FAQ 6.3.3]
% Change data into units
SSb = SSb * (Unit^2);
% Calculate Kb on scenario b
Kb = sqrt(max(WS2 + SSb,0));
% Compute total vega capital for listed currencies under scenario b
K_Girr_Listed_Vega_ScenarioB = sqrt(max(0,(Kb') * Kb + (WS')*(ones(30)*Gamma)*(WS) - Gamma*(WS')*WS));
% Convert K_Girr_Listed_Vega_ScenarioB back into reporting unit
% The number K_Girr_Listed_Vega_ScenarioB should be reported in F42
K_Girr_Listed_Vega_ScenarioB = K_Girr_Listed_Vega_ScenarioB / Unit;
% Output of the girr function: scb
scb = K_Girr_Listed_Vega_ScenarioB;

%% ***************************************************************
% Scenario c
% Load the vega risks contribution on scenario c
SSc = TBsba(6:35,236);
% [Note: As stated on page 121 of the QIS instructions, data input of SSc should include multiplication by rho parameters. These parameters are specified in FAQ 6.3.3]
% Change data into units
SSc = SSc * (Unit^2);
% Calculate Kb on scenario c
Kb = sqrt(max(0,WS2 + SSc));
% Compute total vega capital for listed currencies under scenario c
K_Girr_Listed_Vega_ScenarioC = sqrt(max(0,(Kb') * Kb + (WS')*(ones(30)*Gamma)*(WS) - Gamma*(WS')*WS));
% Convert K_Girr_Listed_Vega_ScenarioC back into reporting unit
% The number K_Girr_Listed_Vega_ScenarioC should be reported in F43
K_Girr_Listed_Vega_ScenarioC = K_Girr_Listed_Vega_ScenarioC / Unit;
% Output of the girr function: scc
scc = K_Girr_Listed_Vega_ScenarioC;

%% ***************************************************************
% Curvature risk
%*****************************************************************
% Load the curvature risk contribution
SCvr = TBsba(6:35,238);
% Change data into units
SCvr = SCvr * Unit;
% Calculate Kb
Kb = max(SCvr, 0);
% Compute total non-linear capital for listed currencies
WS = SCvr;
XbYc = WS*(WS');
% [Apply function Phi]
for b = 1:30
for c = 1:30
if WS(b)<0 && WS(c)<0
XbYc(b,c)=0;
end
end
end
Gamma = 0.25;
K_Girr_Listed_Curvature = sqrt(max((Kb') * Kb + (Gamma)* sum(sum(XbYc)) - sum(Gamma*diag(XbYc)),0));
% Convert Kb and K_Girr_Listed_Curvature back into reporting unit
% The vector Kb should be reported in IC6:IC35
% The number K_Girr_Listed_Curvature should be reported in F44
Kb = Kb / Unit;
K_Girr_Listed_Curvature = K_Girr_Listed_Curvature / Unit;

% Output of the girr function: curvature
curvature = K_Girr_Listed_Curvature;

end